==> jquery-packir-0.1.8.tgz: package/gulpfile.js <==
var gulp = require("gulp"),
    pkg  = require("./package.json"),
    _    = require("lodash");

gulp.task("compile", function() {
    var browserify = require("browserify"),
        source     = require("vinyl-source-stream"),
        umd        = require("gulp-umd"),
        buffer     = require("vinyl-buffer"),
        literalify = require("literalify"),
        uglify     = require("gulp-uglify"),
        rename     = require("gulp-rename"),
        replace    = require("gulp-replace"),
        branch     = require("stream-branch"),
        path       = require("path"),
        duplexer   = require("duplexer2"),
        bundler;

    bundler = browserify();
    bundler.transform(literalify.configure({
        "jquery": "_$",
        "packir": "_packir"
    }));

    bundler.require("./lib/plugin.js", { expose: 'jquery-packir' });

    return bundler.bundle()
        .pipe(source("jquery.packir.js"))
        .pipe(buffer())
        .pipe(replace(/\.catch\(/gi, "['catch']("))
        .pipe(branch({ objectMode: true },
            [
                makeUmd({ template: path.resolve("./build/umd.ejs") }, "ajs"),
                makeUmd({ template: path.resolve("./build/umd.ejs") })
            ]
        ))
        .pipe(gulp.dest("./dist"))
        .pipe(uglify())
        .pipe(rename({ extname: ".min.js" }))
        .pipe(gulp.dest("./dist"));

    function makeUmd(options, type) {
        var first;

        first = umd(_.extend({
            exports: function(file) {
                return 'require("jquery-packir")';
            },
            namespace: function(file) {
                return '$packir';
            },
            dependencies: function(file) {
                return [
                    {
                        name: '_$',
                        amd: 'jquery',
                        cjs: 'jquery',
                        global: 'jQuery'
                    },
                    {
                        name: '_packir',
                        amd: 'packir',
                        cjs: 'packir',
                        global: 'packir'
                    }
                ];
            }
        }, options || {}));

        return duplexer(first, first.pipe(rename({ extname: (type ? "." + type : "") + ".js" })));
    }
});

gulp.task("images", function(done) {
    var jsdom = require("jsdom"),
        fs    = require("fs"),
        url = require('url'),
        http = require('http'),
        sizeOf = require('image-size'),
        async  = require("async");

    jsdom.env({
        url: "http://pixabay.com/en/photos/?q=cat&image_type=photo&horizontal=horizontal&cat=&order=best&per_page=150",
        scripts: ["http://code.jquery.com/jquery.js"],
        done: function (errors, window) {
            var $, images;

            if (errors) {
                done(errors);
                return;
            }

            $ = window.$;

            images = [];

            $(".item img").each(function () {
                images.push("http://pixabay.com" + $(this).attr('src'));
            });

            images = images.filter(function(src) {
                return !/blank\.gif$/.test(src);
            });

            async.map(
                images,
                function(src, next) {
                    http.get(url.parse(src), function(response) {
                        var chunks = [];

                        response
                            .on('data', function (chunk) {
                                chunks.push(chunk);
                            })
                            .on('end', function() {
                                next(null, { src: src, size: sizeOf(Buffer.concat(chunks)) });
                            })
                            .on('error', function(err) {
                                next(err);
                            });
                    });
                },
                function(err, images) {
                    if (err) {
                        done(err);
                        return;
                    }

                    fs.writeFile("./example/data/images.js", _.template(";void function(root) { window.images = <%= json %> }(window);")({json: JSON.stringify(images)}), done);
                }
            );
        }
    });
});

gulp.task("packir", function() {
    var fs = require("fs");

    return fs.createReadStream("./node_modules/packir/dist/packir.js")
        .pipe(fs.createWriteStream("./example/vendor/packir.js"));
});

gulp.task("example", ["packir", "images"]);

gulp.task("default", ["compile", "example"]);

==> jquery-packir-0.5.0.tgz: package/gulpfile.js <==
var gulp = require("gulp"),
    pkg  = require("./package.json"),
    _    = require("lodash");

gulp.task("compile", function() {
    var browserify = require("browserify"),
        source     = require("vinyl-source-stream"),
        umd        = require("gulp-umd"),
        buffer     = require("vinyl-buffer"),
        literalify = require("literalify"),
        uglify     = require("gulp-uglify"),
        rename     = require("gulp-rename"),
        replace    = require("gulp-replace"),
        branch     = require("stream-branch"),
        path       = require("path"),
        duplexer   = require("duplexer2"),
        bundler;

    bundler = browserify();
    bundler.transform(literalify.configure({
        "jquery": "_$",
        "packir": "_packir"
    }));

    bundler.require("./lib/plugin.js", { expose: 'jquery-packir' });

    return bundler.bundle()
        .pipe(source("jquery.packir.js"))
        .pipe(buffer())
        .pipe(replace(/\.catch\(/gi, "['catch']("))
        .pipe(branch({ objectMode: true },
            [
                makeUmd({ template: path.resolve("./build/ajs.ejs") }, "ajs"),
                makeUmd({ template: path.resolve("./build/umd.ejs") })
            ]
        ))
        .pipe(gulp.dest("./dist"))
        .pipe(uglify())
        .pipe(rename({ extname: ".min.js" }))
        .pipe(gulp.dest("./dist"));

    function makeUmd(options, type) {
        var first;

        first = umd(_.extend({
            exports: function(file) {
                return 'require("jquery-packir")';
            },
            namespace: function(file) {
                return 'jquery-packir';
            },
            dependencies: function(file) {
                return [
                    {
                        name: '_$',
                        amd: 'jquery',
                        cjs: 'jquery',
                        global: 'jQuery'
                    },
                    {
                        name: '_packir',
                        amd: 'packir',
                        cjs: 'packir',
                        global: 'packir'
                    }
                ];
            }
        }, options || {}));

        return duplexer(first, first.pipe(rename({ extname: (type ? "." + type : "") + ".js" })));
    }
});

gulp.task("images", function(done) {
    var jsdom = require("jsdom"),
        fs    = require("fs"),
        url = require('url'),
        http = require('http'),
        sizeOf = require('image-size'),
        async  = require("async");

    jsdom.env({
        url: "http://pixabay.com/en/photos/?q=cat&image_type=photo&horizontal=horizontal&cat=&order=best&per_page=150",
        scripts: ["http://code.jquery.com/jquery.js"],
        done: function (errors, window) {
            var $, images;

            if (errors) {
                done(errors);
                return;
            }

            $ = window.$;

            images = [];

            $(".item img").each(function () {
                images.push("http://pixabay.com" + $(this).attr('src'));
            });

            images = images.filter(function(src) {
                return !/blank\.gif$/.test(src);
            });

            async.map(
                images,
                function(src, next) {
                    http.get(url.parse(src), function(response) {
                        var chunks = [];

                        response
                            .on('data', function (chunk) {
                                chunks.push(chunk);
                            })
                            .on('end', function() {
                                next(null, { src: src, size: sizeOf(Buffer.concat(chunks)) });
                            })
                            .on('error', function(err) {
                                next(err);
                            });
                    });
                },
                function(err, images) {
                    if (err) {
                        done(err);
                        return;
                    }

                    fs.writeFile("./example/data/images.js", _.template(";void function(root) { window.images = <%= json %> }(window);")({json: JSON.stringify(images)}), done);
                }
            );
        }
    });
});

gulp.task("packir", function() {
    var fs = require("fs");

    return fs.createReadStream("./node_modules/packir/dist/packir.js")
        .pipe(fs.createWriteStream("./example/vendor/packir.js"));
});

gulp.task("example", ["packir", "images"]);

gulp.task("default", ["compile", "example"]);
